# EIAC Desktop Application

一个基于 Electron 框架的跨平台桌面应用程序，用于访问和管理企业内部应用系统。

## 概述

EIAC Desktop Application 是一个基于 Electron 框架的桌面应用程序。

主要功能包括：

- 🏢 统一的企业应用访问入口
- 📑 多标签页管理
- 🔍 自定义页面缩放
- 🔐 统一的用户认证
- 🐛 故障上报功能
- 🖥️ 跨平台支持（Windows、macOS、Linux）

本项目使用 `npx create-electron-app@latest china-telecom-app --template=vite-typescript` 创建。

## 开发

### 环境要求

- Node.js >= 22.11.0
- npm >= 11.3.0
- Git

### 开发环境设置

1. 克隆仓库
```bash
git clone [repository-url]
cd china-telecom-app
```

2. 安装依赖
```bash
npm install
```

3. 启动开发服务器
```bash
npm run start
```

### 开发指南

- 使用 TypeScript 进行开发
- 遵循 ESLint 规范
- 使用 Prettier 进行代码格式化
- 主要开发文件位于 `src` 目录下
- 使用 IPC 通信进行主进程和渲染进程的通信

## 构建

### 构建命令

```bash
npm run package
```

### 构建配置

- 构建配置位于 `forge.config.js`
- 支持自定义应用图标
- 支持自定义应用名称
- 支持自定义构建目标平台

## 发布

### 发布流程

1. 更新版本号

在确认仓库没有任何未提交的更改后，执行以下命令更新版本号：

```bash
npm version [patch|minor|major]
```

如有未更改的提交，执行以上命令会报错：`npm error Git working directory not clean.`

或者手工编辑 `package.json` 文件，将 `version` 字段更新为新版本号。

2. 构建版本
```bash
npm run package
```

3. 打包版本
```bash
npm run make
```

4. 发布到发布服务器
```bash
npm run publish
```

### 发布注意事项

- 确保版本号正确更新
- 确保所有依赖都是最新的稳定版本
- 确保构建配置正确
- 测试发布版本的功能完整性

## 参考文档

- [Electron](https://www.electronjs.org/) - 跨平台桌面应用框架
- [Electron Forge](https://www.electronforge.io/) - Electron 应用打包工具
- [TypeScript](https://www.typescriptlang.org/) - JavaScript 的超集
- [electron-tabs](https://github.com/brrd/electron-tabs) - Electron 标签页管理
- [vite](https://vite.dev/) - 现代前端构建工具
